pub enum SharedAccess {
WriteAccess(Vec<String>),
ReadOnly(AeadPack),
}Expand description
Access controls for shared vaults.
Variants
WriteAccess(Vec<String>)
List of recipients for a shared vault.
Every recipient is able to write to the shared vault.
ReadOnly(AeadPack)
Private list of recipients managed by an owner.
Only the owner can write to the vault, other recipients can only read.
Implementations