Enum FileContent Copy item path Source pub enum FileContent {
Embedded {
name: String ,
mime: String ,
buffer: SecretBox <Vec <u8 >>,
checksum: [u8 ; 32 ],
},
External {
name: String ,
mime: String ,
checksum: [u8 ; 32 ],
size: u64 ,
path: Option <PathBuf >,
},
}Expand description Variants for embedded and external file secrets.
Fields Mime type for the data.
Use application/octet-stream if no mime-type is available.
The SHA-256 digest of the buffer.
Using the SHA-256 digest allows the checksum to be computed
using the Javascript SubtleCrypto API and in Dart using the
crypto package.
This is used primarily during the public migration export
to identify files that have been extracted to another location
in the archive rather than embedding the binary data.
Encrypted data is stored in an external file.
Fields Mime type for the data.
Use application/octet-stream if no mime-type is available.
The SHA-256 digest of the buffer.
Using the SHA-256 digest allows the checksum to be computed
using the Javascript SubtleCrypto API and in Dart using the
crypto package.
This is used primarily during the public migration export
to identify files that have been extracted to another location
in the archive rather than embedding the binary data.
Size of the encrypted file content.
Optional path to a source file; never encoded or serialized.
Performs copy-assignment from
source.
Read more Decode from the binary reader into self.
Returns the “default value” for a type.
Read more Deserialize this value from the given Serde deserializer.
Read more Encode self into the binary writer.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Serialize this value into the given Serde serializer.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.