Vault

Struct Vault 

pub struct Vault { /* private fields */ }
Vault file storage.

Implementations

Source

impl Vault

pub fn new( id: VaultId, name: String, cipher: Cipher, kdf: KeyDerivation, flags: VaultFlags, ) -> Self

Create a new vault.

pub fn shared_access(&self) -> &SharedAccess

Shared access.

pub fn vault_urn(id: &VaultId) -> Result<Urn, Error>

Get the URN for a vault identifier.

pub fn deriver(&self) -> Box<dyn Deriver<Sha256> + Send + 'static>

Key derivation function deriver.

pub fn set_default_flag(&mut self, value: bool)

Set whether this vault is a default vault.

pub fn set_archive_flag(&mut self, value: bool)

Set whether this vault is an archive vault.

pub fn set_authenticator_flag(&mut self, value: bool)

Set whether this vault is an authenticator vault.

pub fn set_contact_flag(&mut self, value: bool)

Set whether this vault is for contacts.

pub fn set_system_flag(&mut self, value: bool)

Set whether this vault is for system specific information.

pub fn set_device_flag(&mut self, value: bool)

Set whether this vault is for device specific information.

pub fn set_no_sync_flag(&mut self, value: bool)

Set whether this vault should not sync with own devices.

pub fn insert_entry(&mut self, id: SecretId, entry: VaultCommit)

Insert a secret into this vault.

pub fn get(&self, id: &SecretId) -> Option<&VaultCommit>

Get a secret in this vault.

pub async fn encrypt( &self, key: &PrivateKey, plaintext: &[u8], ) -> Result<AeadPack, Error>

Encrypt plaintext using the cipher assigned to this vault.

pub async fn decrypt( &self, key: &PrivateKey, aead: &AeadPack, ) -> Result<Vec<u8>, Error>

Decrypt ciphertext using the cipher assigned to this vault.

pub fn rotate_identifier(&mut self)

Choose a new identifier for this vault.

This is useful when importing a vault and the identifier collides with an existing vault; rather than overwriting the existing vault we can import it alongside by choosing a new identifier.

pub async fn verify(&self, key: &AccessKey) -> Result<(), Error>

Verify an access key.

pub fn iter(&self) -> impl Iterator<Item = (&Uuid, &VaultCommit)>

Iterator for the secret keys and values.

pub fn keys(&self) -> impl Iterator<Item = &Uuid>

Iterator for the secret keys.

pub fn values(&self) -> impl Iterator<Item = &VaultCommit>

Iterator for the secret values.

pub fn len(&self) -> usize

Number of secrets in this vault.

pub fn is_empty(&self) -> bool

Determine if this vault is empty.

pub async fn into_event(&self) -> Result<WriteEvent, Error>

Convert this vault into a create vault event.

Ensures the vault is head-only before encoding into the event.

pub fn commits(&self) -> impl Iterator<Item = (&Uuid, &CommitHash)>

Iterator for the secret keys and commit hashes.

pub fn salt(&self) -> Option<&String>

Get the salt used for passphrase authentication.

pub fn seed(&self) -> Option<&Seed>

Get the seed used for passphrase authentication.

pub fn summary(&self) -> &Summary

Get the summary for this vault.

pub fn flags(&self) -> &VaultFlags

Reference to the vault flags.

pub fn flags_mut(&mut self) -> &mut VaultFlags

Mutable reference to the vault flags.

pub fn id(&self) -> &VaultId

Unique identifier for this vault.

pub fn name(&self) -> &str

Public name for this vault.

pub fn set_name(&mut self, name: String)

Set the public name of this vault.

pub fn cipher(&self) -> &Cipher

Encryption cipher for this vault.

pub fn kdf(&self) -> &KeyDerivation

Key derivation function.

pub fn header(&self) -> &Header

Vault header.

pub fn header_mut(&mut self) -> &mut Header

Mutable vault header.

pub fn data(&self) -> &IndexMap<SecretId, VaultCommit>

Vault data.

pub fn data_mut(&mut self) -> &mut IndexMap<SecretId, VaultCommit>

Mutable vault data.

pub fn meta_data(&self) -> HashMap<&Uuid, &AeadPack>

Get the meta data for all the secrets.